#!/usr/bin/env python3

from pathlib import Path
from json import load

import requests

with open("targets") as f:
    TARGETS = [target.strip() for target in f.readlines()]
with open("all.Dockerfile") as f:
    TEMPLATE = f.read()

ALL = "./memmos.laas.fr:5000/gepetto/buildfarm/all"
CONF = ">> /opt/openrobots/etc/robotpkg.conf\n"
CACHE = "--mount=type=cache,target=/root/robotpkg/distfiles"

COMMENTED = {
    "sot-hrprtc-hrp2": "too old",
    "sot-hrp2-v3": "too old",
    "hrp2-14-description": "private",
    "pyrene-motions": "broken",
    "openhrp3-simulator-wo-rtm": "it cant find QMetaType from gepetto/viewer/config-osg.h",
    "hpp-doc": "not relevant",
    "example-adder": "tmp",
}
COMMENTED_TARGETS = {}
NO_TESTS = [
    "rqt-dynamic-graph",
    "py-sot-talos-balance",
    "tiago-robot",
    "talos-metapkg-ros-control-sot",
    "py-multicontact-api" "hpp-rbprm",
]
NO_TESTS_TARGETS = {
    "hpp-constraints": ["archlinux", "stretch", "16.04"],
    "hpp-core": ["archlinux", "stretch", "16.04"],
    "py-hpp-corbaserver": ["stretch", "16.04"],
    "hpp-pinocchio": ["stretch", "16.04"],
    "py-hpp-rbprm-corba": ["fedora34"],
}
HIDDEN_DEPS = {}

RAINBOARD_URL = "https://rainboard.laas.fr/projects/ordered"
RAINBOARD_DATA = requests.get(RAINBOARD_URL).json()["ret"]
for target in TARGETS:
    user = "home/user" if target == "archlinux" else "root"
    path = ALL
    if target in ["ferrum"]:
        path = path.replace("memmos.laas.fr:5000", "gitlab.laas.fr:4567")
    with (Path(path) / target / "Dockerfile").open("w") as f:
        f.write(
            f"FROM memmos.laas.fr:5000/gepetto/buildfarm/robotpkg:{target} as main\n\n"
        )
        f.write(TEMPLATE)
        for category, project, _, deps in RAINBOARD_DATA:
            f.write(f"\nFROM main as {project}\n")
            for dep in deps + HIDDEN_DEPS.get(project, []):
                f.write(f"COPY --from={dep} /opt/openrobots /opt/openrobots\n")
            f.write(f"\nWORKDIR /{user}/robotpkg/{category}/{project}\n")
            if project == "pinocchio":
                f.write(
                    "RUN sed -i 's/-DBUILD_TESTING=OFF/-DBUILD_TESTING=ON/' Makefile\n"
                )
            if project in COMMENTED:
                f.write(f"# TODO {COMMENTED[project]}\n#")
            if project in COMMENTED_TARGETS and target in COMMENTED_TARGETS[project]:
                f.write(f"# TODO not on {target}\n#")
            if project in NO_TESTS:
                f.write("# TODO test fail\n")
            if project in NO_TESTS_TARGETS and target in NO_TESTS_TARGETS[project]:
                f.write(f"# TODO test fail on {target}\n")
            f.write(f"RUN {CACHE} sccache -s && make install")
            if project not in NO_TESTS and (
                project not in NO_TESTS_TARGETS
                or target not in NO_TESTS_TARGETS[project]
            ):
                f.write(" && build=$(make show-var VARNAME=CONFIGURE_DIRS)")
                f.write(" && pushd $(make show-var VARNAME=WRKSRC) && pushd $build")
                f.write(" && make test && popd && popd")
            f.write(f" && make clean # {project}\n")

        f.write("\nFROM main as final\n")
        for _, project, _, _ in RAINBOARD_DATA:
            f.write(f"COPY --from={project} /opt/openrobots /opt/openrobots\n")
