#!/bin/bash -eux

# update one project

PROJECT=$1
REGISTRY=${2:-"memmos.laas.fr:5000"}

function has_binaries {
    # Check if binaries are available on robotpkg for a target
    if [[ "$1" == "14.04" || "$1" == "16.04" || "$1" == "18.04" || "$1" == "20.04" ]]
    then return 0
    elif [[ "$1" == "dubnium" || "$1" == "erbium" || "$1" == "ferrum" ]]
    then return 0
    elif [[ "$1" == "jessie" || "$1" == "stretch" || "$1" == "buster" ]]
    then return 0
    else return 1
    fi
}

function is_private {
    # Check if we can publish that
    if [[ "$1" == "dubnium" || "$1" == "erbium" || "$1" == "ferrum" ]]
    then return 0
    else return 1
    fi
}

function no_py2 {
    # Check if python2 is available on robotpkg for a target
    if [[ "$1" == "20.04" ]]
    then return 0
    else return 1
    fi
}


function dpatch {
    # patch the containers that need it for a target
    has_binaries "$1" || return 0
    while read -r namespace project robotpkg
    do
        [[ $# == 2 && "$project" != "$2" ]] && continue
        grep -q sot-pattern-generator <<< "$project" && [[ "$1" == "20.04" || "$1" == "stretch" || "$1" == "buster" ]] && continue
        grep -q py2 <<< $robotpkg && no_py2 "$1" && continue
        echo -e "\n === patch $namespace -- $project -- $robotpkg === \n"
        docker build --add-host "archives.basestation:10.68.1.1" \
            --build-arg REGISTRY="memmos.laas.fr:5000" \
            --build-arg NAMESPACE="$namespace" \
            --build-arg PROJECT="$project" \
            --build-arg ROBOTPKG="$robotpkg" \
            --build-arg DISTRO="$1" \
            -f patches/Dockerfile \
            -t "memmos.laas.fr:5000/$namespace/$project/$robotpkg:$1" .
    done < patches/list
    echo "patch done"
}


curl "https://rainboard.laas.fr/docker?cmd=build&robotpkg__project__slug=$PROJECT" | sort -u | sed 's/docker build /docker build --no-cache /' | bash -x
if grep -q "$PROJECT" patches/list
then
    while read target
    do
        dpatch "$target" "$PROJECT"
    done < targets
fi
curl "https://rainboard.laas.fr/docker?cmd=push&robotpkg__project__slug=$PROJECT" | sort -u | bash -x
